@@ -205,14 +205,32 @@ class Customer(object):
                         ),
                     params={'customer': self.name, 'fromdate': last_date}
                     )
-                if response:
+                LOGS.logger.info("essai {} de {}".format(i, self.name))
+                infos = response['content']
+                LOGS.logger.warn('Value {}'.format(infos))
+                if infos['status']:
                     OK = True
-            except requests.exceptions.ConnectTimeout:
-                LOGS.logger.info("essai ERROR {} de {}".format(i, self.name))
+            except requests.exceptions.Timeout:
+                LOGS.logger.info("essai TimeoutError {} de {}".format(
+                    i,
+                    self.name
+                    ))
+                time.sleep(60)
+                continue
+            except ValueError:
+                LOGS.logger.info("essai ValueError {} de {}".format(
+                    i,
+                    self.name
+                    ))
+                time.sleep(60)
+                continue
+            except Exception:
+                LOGS.logger.info("essai ExceptionError {} de {}".format(
+                    i,
+                    self.name
+                    ))
                 time.sleep(60)
                 continue
-        infos = response['content']
-        LOGS.logger.warn('Value {}'.format(infos))
         # nill_condition = (
         #    'refnum' not in infos or
         #    infos['product'] not in [i.name for i in product.Product.all()]
