@@ -34,6 +34,7 @@ class Product_GP(object):
         self.send_sms = kwargs.get('send_sms', 'faux')
         self.username = kwargs.get('username', 'fup-services')
         self.type_ident = kwargs.get('type_ident', 'msisdn')
+        self.produit_nom = kwargs.get('produit_nom')
 
     def __repr__(self):
         return(
@@ -42,6 +43,7 @@ class Product_GP(object):
             'email {email}, '
             'phone {phone}, '
             'type_ident {type_ident}, '
+            'produit_nom {produit_nom}, '
             'limit {limit}>'
             ).format(
             name=self.customer_name,
@@ -49,6 +51,7 @@ class Product_GP(object):
             email=self.email,
             phone=self.phonenumber,
             type_ident=self.type_ident,
+            produit_nom=self.produit_nom,
             limit=self.limit
             )
 
@@ -86,7 +89,8 @@ class Product_GP(object):
                     'email': info.get('mail'),
                     'phonenumber': info.get('phone'),
                     'send_sms': info['send_sms'].lower(),
-                    'type_ident': info['type_ident'].lower()
+                    'type_ident': info['type_ident'].lower(),
+                    'produit_nom': info['produit_nom'].lower()
                     }
                 result.append(Product_GP(name, ident, **kwargs))
             return result
@@ -221,7 +225,7 @@ class Product_GP(object):
             if self.notif_mail_percentage:
                 if percentage >= self.notif_mail_percentage:
                     if self.send_sms == 'faux':
-                        message = (
+                        """message = (
                             "Cher client, vous vous approchez "
                             "d’une consommation mensuelle équivalente "
                             "au double de la consommation moyenne des "
@@ -232,9 +236,43 @@ class Product_GP(object):
                             "dernières consommations sur le site "
                             "http://espace-client.blueline.mg"
                             )
+                        """
+                        message = (
+                                "Cher Mr/Mme {name}, ayant souscrit au produit"
+                                " {produit},\n\nVotre consommation internet"
+                                " des 30 derniers jours atteint le double de"
+                                " la consommation moyenne des clients. Afin de"
+                                " protéger la qualité de service de l’ensemble"
+                                " de nos clients et conformément à nos"
+                                " conditions générales de ventes, nous vous"
+                                " informons que nous serons peut être amenés"
+                                " à diminuer le débit de votre connexion sans"
+                                " toutefois la couper.\n\nPour éviter cela, "
+                                " nous vous recommandons de réduire les usages"
+                                " intenses tels que le téléchargements de"
+                                " fichiers volumineux, l’usage des sites de"
+                                " streaming video comme Youtube et Dailymotion"
+                                " , etc….\n\nPour vous aider à maitriser votre"
+                                " usage, nous vous invitons à vous connecter"
+                                " sur votre espace client :"
+                                " http://espace-client.blueline.mg pour"
+                                " connaitre les informations sur votre "
+                                " consommation.\n\nSi vous avez égaré votre "
+                                " identifiant et votre mot de passe, merci de"
+                                " contacter le service client 0 391 391 391,\n"
+                                "\nBlueline vous remercie de votre"
+                                " compréhension."
+                                ).format(
+                                name=self.customer_name,
+                                produit=self.produit_nom
+                                )
+                        obj = (
+                            "Notification de consommation élevée sur le"
+                            " produit {produit}"
+                            ).format(produit=self.produit_nom)
                     elif self.send_sms == 'vrai':
                         if self.type_ident == 'mac':
-                            message = (
+                            """message = (
                                 "Cher client {name}, Vous vous approchez "
                                 "d’une consommation mensuelle équivalente "
                                 "au double de la consommation moyenne des "
@@ -245,21 +283,60 @@ class Product_GP(object):
                                 "dernières consommations sur le site "
                                 "http://espace-client.blueline.mg"
                                 ).format(name=self.customer_name)
+                            """
+                            message = (
+                                "Cher Mr/Mme {name}, ayant souscrit au produit"
+                                " {produit},\n\nVotre consommation internet"
+                                " des 30 derniers jours atteint le double de"
+                                " la consommation moyenne des clients. Afin de"
+                                " protéger la qualité de service de l’ensemble"
+                                " de nos clients et conformément à nos"
+                                " conditions générales de ventes, nous vous"
+                                " informons que nous serons peut être amenés"
+                                " à diminuer le débit de votre connexion sans"
+                                " toutefois la couper.\n\nPour éviter cela, "
+                                " nous vous recommandons de réduire les usages"
+                                " intenses tels que le téléchargements de"
+                                " fichiers volumineux, l’usage des sites de"
+                                " streaming video comme Youtube et Dailymotion"
+                                " , etc….\n\nPour vous aider à maitriser votre"
+                                " usage, nous vous invitons à vous connecter"
+                                " sur votre espace client :"
+                                " http://espace-client.blueline.mg pour"
+                                " connaitre les informations sur votre "
+                                " consommation.\n\nSi vous avez égaré votre "
+                                " identifiant et votre mot de passe, merci de"
+                                " contacter le service client 0 391 391 391,\n"
+                                "\nBlueline vous remercie de votre"
+                                " compréhension."
+                                ).format(
+                                name=self.customer_name,
+                                produit=self.produit_nom
+                                )
+                            obj = (
+                                "Notification de consommation élevée sur le"
+                                " produit {produit}"
+                                ).format(produit=self.produit_nom)
                         elif self.type_ident == 'msisdn':
                             message = (
-                                "Cher client {name}, Vous avez "
+                                "Cher client {name},\n\nVous avez "
                                 "consommé {percentage}% de votre forfait.\n"
                                 "Vous pouvez aller gratuitement sur le site "
                                 "http://espace-client.blueline.mg pour "
-                                "recharger en prépayé."
+                                "recharger en prépayé.\n\nBlueline vous "
+                                "remercie de votre compréhension."
                                 ).format(
                                 percentage=self.notif_mail_percentage,
                                 name=self.customer_name
                                 )
+                            obj = (
+                                "Notification de consommation élevée sur le"
+                                " produit {produit}"
+                                ).format(produit=self.produit_nom)
                         elif self.type_ident == 'ident':
                             limit = round(self.limit / 1000000000)
                             message = (
-                                "Cher client {name}, Vous avez atteint "
+                                "Cher client {name},\n\nVous avez atteint "
                                 "{x} Go sur les {limit} Go "
                                 "de la politique de bon usage de votre "
                                 "offre Internet.\nArrivé à {limit} Go "
@@ -267,7 +344,9 @@ class Product_GP(object):
                                 "sera restreint.\nNous vous invitons à "
                                 "consulter vos dernières consommations "
                                 "sur votre espace client "
-                                "http://espace-client.blueline.mg"
+                                "http://espace-client.blueline.mg \n\n"
+                                "Blueline vous remercie de votre "
+                                "compréhension."
                                 ).format(
                                 x=round(
                                     self.notif_mail_percentage * limit / 100
@@ -275,10 +354,14 @@ class Product_GP(object):
                                 name=self.customer_name,
                                 limit=limit
                                 )
+                            obj = (
+                                "Notification de consommation élevée sur le"
+                                " produit {produit}"
+                                ).format(produit=self.produit_nom)
                     # envoyer msg
                     content = MIMEText(message, 'plain', 'utf-8')
                     msg = MIMEMultipart()
-                    msg['Subject'] = '[blueline] Notification Over-quota'
+                    msg['Subject'] = ('[blueline] {object}').format(object=obj)
                     msg['From'] = CONFIG['ALERT']['from_1']
                     msg['To'] = self.email
                     msg.attach(content)
